Struct Ccgr0
Source #[repr(transparent)]
pub struct Ccgr0(pub u32);
CCM Clock Gating Register 0
aips_tz1 clocks (aips_tz1_clk_enable)
aips_tz1 clocks (aips_tz1_clk_enable)
aips_tz2 clocks (aips_tz2_clk_enable)
aips_tz2 clocks (aips_tz2_clk_enable)
mqs clock ( mqs_hmclk_clock_enable)
mqs clock ( mqs_hmclk_clock_enable)
sim_m or sim_main register access clock (sim_m_mainclk_r_enable)
sim_m or sim_main register access clock (sim_m_mainclk_r_enable)
dcp clock (dcp_clk_enable)
dcp clock (dcp_clk_enable)
lpuart3 clock (lpuart3_clk_enable)
lpuart3 clock (lpuart3_clk_enable)
can1 clock (can1_clk_enable)
can1 clock (can1_clk_enable)
can1_serial clock (can1_serial_clk_enable)
can1_serial clock (can1_serial_clk_enable)
can2 clock (can2_clk_enable)
can2 clock (can2_clk_enable)
can2_serial clock (can2_serial_clk_enable)
can2_serial clock (can2_serial_clk_enable)
trace clock (trace_clk_enable)
trace clock (trace_clk_enable)
gpt2 bus clocks (gpt2_bus_clk_enable)
gpt2 bus clocks (gpt2_bus_clk_enable)
gpt2 serial clocks (gpt2_serial_clk_enable)
gpt2 serial clocks (gpt2_serial_clk_enable)
lpuart2 clock (lpuart2_clk_enable)
lpuart2 clock (lpuart2_clk_enable)
gpio2_clocks (gpio2_clk_enable)
gpio2_clocks (gpio2_clk_enable)
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.