Struct Ccgr2
Source #[repr(transparent)]
pub struct Ccgr2(pub u32);
CCM Clock Gating Register 2
ocram_exsc clock (ocram_exsc_clk_enable)
ocram_exsc clock (ocram_exsc_clk_enable)
csi clock (csi_clk_enable)
csi clock (csi_clk_enable)
iomuxc_snvs clock (iomuxc_snvs_clk_enable)
iomuxc_snvs clock (iomuxc_snvs_clk_enable)
lpi2c1 clock (lpi2c1_clk_enable)
lpi2c1 clock (lpi2c1_clk_enable)
lpi2c2 clock (lpi2c2_clk_enable)
lpi2c2 clock (lpi2c2_clk_enable)
lpi2c3 clock (lpi2c3_clk_enable)
lpi2c3 clock (lpi2c3_clk_enable)
OCOTP_CTRL clock (ocotp_clk_enable)
OCOTP_CTRL clock (ocotp_clk_enable)
xbar3 clock (xbar3_clk_enable)
xbar3 clock (xbar3_clk_enable)
ipmux1 clock (ipmux1_clk_enable)
ipmux1 clock (ipmux1_clk_enable)
ipmux2 clock (ipmux2_clk_enable)
ipmux2 clock (ipmux2_clk_enable)
ipmux3 clock (ipmux3_clk_enable)
ipmux3 clock (ipmux3_clk_enable)
xbar1 clock (xbar1_clk_enable)
xbar1 clock (xbar1_clk_enable)
xbar2 clock (xbar2_clk_enable)
xbar2 clock (xbar2_clk_enable)
gpio3 clock (gpio3_clk_enable)
gpio3 clock (gpio3_clk_enable)
lcd clocks (lcd_clk_enable)
lcd clocks (lcd_clk_enable)
pxp clocks (pxp_clk_enable)
pxp clocks (pxp_clk_enable)
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.