#[repr(transparent)]pub struct Ccr(pub u32);Expand description
CCM Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Ccr
impl Ccr
Sourcepub const fn oscnt(&self) -> u8
pub const fn oscnt(&self) -> u8
Oscillator ready counter value. These bits define value of 32KHz counter, that serve as counter for oscillator lock time (count to n+1 ckil’s). This is used for oscillator lock time. Current estimation is ~5ms. This counter will be used in ignition sequence and in wake from stop sequence if sbyos bit was defined, to notify that on chip oscillator output is ready for the dpll_ip to use and only then the gate in dpll_ip can be opened.
Sourcepub const fn set_oscnt(&mut self, val: u8)
pub const fn set_oscnt(&mut self, val: u8)
Oscillator ready counter value. These bits define value of 32KHz counter, that serve as counter for oscillator lock time (count to n+1 ckil’s). This is used for oscillator lock time. Current estimation is ~5ms. This counter will be used in ignition sequence and in wake from stop sequence if sbyos bit was defined, to notify that on chip oscillator output is ready for the dpll_ip to use and only then the gate in dpll_ip can be opened.
Sourcepub const fn cosc_en(&self) -> CoscEn
pub const fn cosc_en(&self) -> CoscEn
On chip oscillator enable bit - this bit value is reflected on the output cosc_en
Sourcepub const fn set_cosc_en(&mut self, val: CoscEn)
pub const fn set_cosc_en(&mut self, val: CoscEn)
On chip oscillator enable bit - this bit value is reflected on the output cosc_en
Sourcepub const fn reg_bypass_count(&self) -> RegBypassCount
pub const fn reg_bypass_count(&self) -> RegBypassCount
Counter for analog_reg_bypass signal assertion after standby voltage request by PMIC_STBY_REQ
Sourcepub const fn set_reg_bypass_count(&mut self, val: RegBypassCount)
pub const fn set_reg_bypass_count(&mut self, val: RegBypassCount)
Counter for analog_reg_bypass signal assertion after standby voltage request by PMIC_STBY_REQ
Sourcepub const fn set_rbc_en(&mut self, val: RbcEn)
pub const fn set_rbc_en(&mut self, val: RbcEn)
Enable for REG_BYPASS_COUNTER