nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Cgpr

Struct Cgpr 

#[repr(transparent)]
pub struct Cgpr(pub u32);
CCM General Purpose Register

Tuple Fields

0: u32

Implementations

Source

impl Cgpr

pub const fn pmic_delay_scaler(&self) -> PmicDelayScaler

Defines clock dividion of clock for stby_count (pmic delay counter)

pub const fn set_pmic_delay_scaler(&mut self, val: PmicDelayScaler)

Defines clock dividion of clock for stby_count (pmic delay counter)

pub const fn efuse_prog_supply_gate(&self) -> EfuseProgSupplyGate

Defines the value of the output signal cgpr_dout[4]. Gate of program supply for efuse programing

pub const fn set_efuse_prog_supply_gate(&mut self, val: EfuseProgSupplyGate)

Defines the value of the output signal cgpr_dout[4]. Gate of program supply for efuse programing

pub const fn sys_mem_ds_ctrl(&self) -> SysMemDsCtrl

System memory DS control

pub const fn set_sys_mem_ds_ctrl(&mut self, val: SysMemDsCtrl)

System memory DS control

pub const fn fpl(&self) -> Fpl

Fast PLL enable.

pub const fn set_fpl(&mut self, val: Fpl)

Fast PLL enable.

pub const fn int_mem_clk_lpm(&self) -> IntMemClkLpm

Control for the Deep Sleep signal to the Arm Platform memories with additional control logic based on the Arm WFI signal

pub const fn set_int_mem_clk_lpm(&mut self, val: IntMemClkLpm)

Control for the Deep Sleep signal to the Arm Platform memories with additional control logic based on the Arm WFI signal