#[repr(transparent)]pub struct Cs2cdr(pub u32);Expand description
CCM Clock Divider Register
Tuple Fields
0: u32Implementations
Sourceimpl Cs2cdr
impl Cs2cdr
Sourcepub const fn sai2_clk_podf(&self) -> Sai2ClkPodf
pub const fn sai2_clk_podf(&self) -> Sai2ClkPodf
Divider for sai2 clock podf. The input clock to this divider should be lower than 300Mhz, the predivider can be used to achieve this.
Sourcepub const fn set_sai2_clk_podf(&mut self, val: Sai2ClkPodf)
pub const fn set_sai2_clk_podf(&mut self, val: Sai2ClkPodf)
Divider for sai2 clock podf. The input clock to this divider should be lower than 300Mhz, the predivider can be used to achieve this.
Sourcepub const fn sai2_clk_pred(&self) -> Sai2ClkPred
pub const fn sai2_clk_pred(&self) -> Sai2ClkPred
Divider for sai2 clock pred.Divider should be updated when output clock is gated.
Sourcepub const fn set_sai2_clk_pred(&mut self, val: Sai2ClkPred)
pub const fn set_sai2_clk_pred(&mut self, val: Sai2ClkPred)
Divider for sai2 clock pred.Divider should be updated when output clock is gated.