nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Cscdr3

Struct Cscdr3 

#[repr(transparent)]
pub struct Cscdr3(pub u32);
CCM Serial Clock Divider Register 3

Tuple Fields

0: u32

Implementations

Source

impl Cscdr3

pub const fn csi_clk_sel(&self) -> CsiClkSel

Selector for csi_mclk multiplexer

pub const fn set_csi_clk_sel(&mut self, val: CsiClkSel)

Selector for csi_mclk multiplexer

pub const fn csi_podf(&self) -> CsiPodf

Post divider for csi_mclk. Divider should be updated when output clock is gated.

pub const fn set_csi_podf(&mut self, val: CsiPodf)

Post divider for csi_mclk. Divider should be updated when output clock is gated.